.. include:: ../references.txt

.. _dev:

***********************
Developer documentation
***********************

The developer documentation is a collection of notes for Gammapy developers and maintainers.

If something is not covered here, have a look at the very extensive Astropy developer documentation
`here <http://docs.astropy.org/en/latest/#developer-documentation>`__,
we do most things the same way.

But you don't have to read all this stuff if you want to contribute something to Gammapy.

We're happy to help out with any Gammapy-related questions or issues!

.. _dev-contact:

Contact points
--------------

If you want to talk about Gammapy, what are the options?

* You can always post on the `Gammapy mailing list`_!
  E.g. if you have an issue with Gammapy installation, analysis, a feature request or found a possible issue.
* You can also file and issue or pull request on the `Gammapy Github page`_.
  Making an account on Github takes only a minute and is free.
  Github is where Gammapy development takes place, i.e. anything that might / will lead
  to a change to the Gammapy code or documentation will eventually result in a pull request on Github.
* Often it's unclear if some issue (e.g. an error during installation) is the result of you executing
  the wrong command, or an actual issue in Gammapy that must be addressed by a documentation or code change.
  In those cases we suggest you post on the mailing list first.
* We have a `Slack`_ set up for Gammapy developer chat. You can use it via the Slack app or from your
  web browser at `Gammapy on Slack`_. If you need help with git, Github, Python or have questions about
  Github development (e.g. how to run tests, build the docs, ...), i.e. chat that isn't directly related
  to an issue or pull request on Github, you can use Slack.
* If you want to have a non-public conversation about Gammapy, or added to the Gammapy slack, please email `Christoph Deil`_.


Pages
-----

.. toctree::
  :maxdepth: 1

  intro
  setup
  howto
  release
  pigs/index
  dataformats
